@@ -20,8 +20,8 @@ import time
 
 from pprint import pprint
 
-
 from .exceptions import CommunicationError
+from ..utils.base_serial import BaseSerialPort
 
 
 class xatLabsRGBDSAController:
@@ -55,7 +55,7 @@ class xatLabsRGBDSAController:
 
     def __init__(self, port, debug = False, exclusive = True, no_dtr = False):
         self.debug = debug
-        if isinstance(port, serial.Serial):
+        if isinstance(port, serial.Serial) or isinstance(port, BaseSerialPort):
             self.port = port
         else:
             self.port = serial.Serial()
